"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.trading_api import TradingApi  # noqa: E501


class TestTradingApi(unittest.TestCase):
    """TradingApi unit test stubs"""

    def setUp(self):
        self.api = TradingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_user_account_order(self):
        """Test case for cancel_user_account_order

        Cancel open order in account  # noqa: E501
        """
        pass

    def test_get_calculated_trade_impact_by_id(self):
        """Test case for get_calculated_trade_impact_by_id

        Return details of a specific trade before it's placed  # noqa: E501
        """
        pass

    def test_get_calculated_trades_impact(self):
        """Test case for get_calculated_trades_impact

        Return the impact of placing a series of trades on the portfolio  # noqa: E501
        """
        pass

    def test_get_order_impact(self):
        """Test case for get_order_impact

        Check impact of trades on account.  # noqa: E501
        """
        pass

    def test_get_user_account_quotes(self):
        """Test case for get_user_account_quotes

        Get symbol quotes  # noqa: E501
        """
        pass

    def test_modify_calculated_trade_by_id(self):
        """Test case for modify_calculated_trade_by_id

        Modify units of a trade before it is placed  # noqa: E501
        """
        pass

    def test_place_calculated_trades(self):
        """Test case for place_calculated_trades

        Place orders for the CalculatedTrades in series  # noqa: E501
        """
        pass

    def test_place_force_order(self):
        """Test case for place_force_order

        Place a trade with NO validation.  # noqa: E501
        """
        pass

    def test_place_oco_order(self):
        """Test case for place_oco_order

        Place a OCO (One Cancels Other) order  # noqa: E501
        """
        pass

    def test_place_order(self):
        """Test case for place_order

        Place order  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
