"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import sys
import unittest

import snaptrade_client
from snaptrade_client.model.manual_trade import ManualTrade
from snaptrade_client.model.manual_trade_balance import ManualTradeBalance
globals()['ManualTrade'] = ManualTrade
globals()['ManualTradeBalance'] = ManualTradeBalance
from snaptrade_client.model.manual_trade_and_impact import ManualTradeAndImpact


class TestManualTradeAndImpact(unittest.TestCase):
    """ManualTradeAndImpact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testManualTradeAndImpact(self):
        """Test ManualTradeAndImpact"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ManualTradeAndImpact()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
