"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.authentication_api import AuthenticationApi  # noqa: E501


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self):
        self.api = AuthenticationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_snap_trade_user(self):
        """Test case for delete_snap_trade_user

        Delete user from SnapTrade, disabling all brokerage authorizations and permanently deleting all data associated with the user  # noqa: E501
        """
        pass

    def test_get_user_jwt(self):
        """Test case for get_user_jwt

        Obtains an encrypted JWT tokens that should be decrypted on a user's local device  # noqa: E501
        """
        pass

    def test_list_snap_trade_users(self):
        """Test case for list_snap_trade_users

        Get a list of all SnapTrade users you've registered on our platform  # noqa: E501
        """
        pass

    def test_login_snap_trade_user(self):
        """Test case for login_snap_trade_user

        Generate a redirect URI to securely login a user to the SnapTrade Connection Portal  # noqa: E501
        """
        pass

    def test_register_snap_trade_user(self):
        """Test case for register_snap_trade_user

        Register user with SnapTrade in order to create secure brokerage authorizations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
