"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.connections_api import ConnectionsApi  # noqa: E501


class TestConnectionsApi(unittest.TestCase):
    """ConnectionsApi unit test stubs"""

    def setUp(self):
        self.api = ConnectionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_detail_brokerage_authorization(self):
        """Test case for detail_brokerage_authorization

        Get detail of a specific brokerage authorizations for the user  # noqa: E501
        """
        pass

    def test_list_brokerage_authorizations(self):
        """Test case for list_brokerage_authorizations

        List all brokerage authorizations for the user  # noqa: E501
        """
        pass

    def test_remove_brokerage_authorization(self):
        """Test case for remove_brokerage_authorization

        Remove a brokerage authorization.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
