"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.error_logs_api import ErrorLogsApi  # noqa: E501


class TestErrorLogsApi(unittest.TestCase):
    """ErrorLogsApi unit test stubs"""

    def setUp(self):
        self.api = ErrorLogsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_list_user_errors(self):
        """Test case for list_user_errors

        Retrieve error logs on behalf of your SnapTrade users  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
