"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import sys
import unittest

import snaptrade_client
from snaptrade_client.model.account_simple import AccountSimple
from snaptrade_client.model.currency import Currency
from snaptrade_client.model.options_symbol import OptionsSymbol
from snaptrade_client.model.symbol import Symbol
globals()['AccountSimple'] = AccountSimple
globals()['Currency'] = Currency
globals()['OptionsSymbol'] = OptionsSymbol
globals()['Symbol'] = Symbol
from snaptrade_client.model.universal_activity import UniversalActivity


class TestUniversalActivity(unittest.TestCase):
    """UniversalActivity unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUniversalActivity(self):
        """Test UniversalActivity"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UniversalActivity()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
