"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.reference_data_api import ReferenceDataApi  # noqa: E501


class TestReferenceDataApi(unittest.TestCase):
    """ReferenceDataApi unit test stubs"""

    def setUp(self):
        self.api = ReferenceDataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_currency_exchange_rate_pair(self):
        """Test case for get_currency_exchange_rate_pair

        Return the exchange rate of a currency pair  # noqa: E501
        """
        pass

    def test_get_partner_info(self):
        """Test case for get_partner_info

        Get metadata related to Snaptrade partner  # noqa: E501
        """
        pass

    def test_get_security_types(self):
        """Test case for get_security_types

        List of all security types.  # noqa: E501
        """
        pass

    def test_get_stock_exchanges(self):
        """Test case for get_stock_exchanges

        Return list of stock exchanges on Passiv and their suffixes  # noqa: E501
        """
        pass

    def test_get_symbols(self):
        """Test case for get_symbols

        Search for symbols  # noqa: E501
        """
        pass

    def test_get_symbols_by_ticker(self):
        """Test case for get_symbols_by_ticker

        Get details of a symbol by the ticker  # noqa: E501
        """
        pass

    def test_list_all_brokerage_authorization_type(self):
        """Test case for list_all_brokerage_authorization_type

        List of all brokerage authorization types  # noqa: E501
        """
        pass

    def test_list_all_brokerages(self):
        """Test case for list_all_brokerages

        List of all brokerages.  # noqa: E501
        """
        pass

    def test_list_all_currencies(self):
        """Test case for list_all_currencies

        List of all supported currencies  # noqa: E501
        """
        pass

    def test_list_all_currencies_rates(self):
        """Test case for list_all_currencies_rates

        Return the exchange rates of all supported currencies  # noqa: E501
        """
        pass

    def test_symbol_search_user_account(self):
        """Test case for symbol_search_user_account

        Search for symbols that are supported by a brokerage account using a substring  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
