"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import sys
import unittest

import snaptrade_client
from snaptrade_client.model.balance import Balance
from snaptrade_client.model.brokerage_authorization import BrokerageAuthorization
from snaptrade_client.model.calculated_trade import CalculatedTrade
from snaptrade_client.model.excluded_asset import ExcludedAsset
from snaptrade_client.model.portfolio_group_settings import PortfolioGroupSettings
from snaptrade_client.model.position import Position
from snaptrade_client.model.target_asset import TargetAsset
from snaptrade_client.model.universal_symbol import UniversalSymbol
globals()['Balance'] = Balance
globals()['BrokerageAuthorization'] = BrokerageAuthorization
globals()['CalculatedTrade'] = CalculatedTrade
globals()['ExcludedAsset'] = ExcludedAsset
globals()['PortfolioGroupSettings'] = PortfolioGroupSettings
globals()['Position'] = Position
globals()['TargetAsset'] = TargetAsset
globals()['UniversalSymbol'] = UniversalSymbol
from snaptrade_client.model.portfolio_group_info import PortfolioGroupInfo


class TestPortfolioGroupInfo(unittest.TestCase):
    """PortfolioGroupInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPortfolioGroupInfo(self):
        """Test PortfolioGroupInfo"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PortfolioGroupInfo()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
