"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import unittest

import snaptrade_client
from snaptrade_client.api.transactions_and_reporting_api import TransactionsAndReportingApi  # noqa: E501


class TestTransactionsAndReportingApi(unittest.TestCase):
    """TransactionsAndReportingApi unit test stubs"""

    def setUp(self):
        self.api = TransactionsAndReportingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_activities(self):
        """Test case for get_activities

        Get transaction history for a user  # noqa: E501
        """
        pass

    def test_get_reporting_custom_range(self):
        """Test case for get_reporting_custom_range

        Get performance information for a specific timeframe  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
