"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import sys
import unittest

import snaptrade_client
from snaptrade_client.model.cash_restriction import CashRestriction
globals()['CashRestriction'] = CashRestriction
from snaptrade_client.model.account import Account


class TestAccount(unittest.TestCase):
    """Account unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAccount(self):
        """Test Account"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Account()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
