"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Generated by: https://konfigthis.com
"""


import sys
import unittest

import snaptrade_client
from snaptrade_client.model.monthly_dividends import MonthlyDividends
from snaptrade_client.model.net_contributions import NetContributions
from snaptrade_client.model.net_dividend import NetDividend
from snaptrade_client.model.past_value import PastValue
from snaptrade_client.model.sub_period_return_rate import SubPeriodReturnRate
globals()['MonthlyDividends'] = MonthlyDividends
globals()['NetContributions'] = NetContributions
globals()['NetDividend'] = NetDividend
globals()['PastValue'] = PastValue
globals()['SubPeriodReturnRate'] = SubPeriodReturnRate
from snaptrade_client.model.performance_custom import PerformanceCustom


class TestPerformanceCustom(unittest.TestCase):
    """PerformanceCustom unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPerformanceCustom(self):
        """Test PerformanceCustom"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PerformanceCustom()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
